@@ -2,7 +2,7 @@
 
 """Idiomatic conversion between URIs and compact URIs (CURIEs)."""
 
-from .api import Converter
+from .api import Converter, chain
 from .sources import (
     get_bioregistry_converter,
     get_go_converter,
@@ -15,6 +15,7 @@ from .version import get_version
 
 __all__ = [
     "Converter",
+    "chain",
     "get_version",
     "get_obo_converter",
     "get_prefixcommons_converter",
