@@ -2,14 +2,15 @@
 
 """Data structures and algorithms for :mod:`curies`."""
 
-from collections import defaultdict
-from typing import List, Mapping, Optional, Tuple, Union
+from collections import ChainMap, defaultdict
+from typing import List, Mapping, Optional, Sequence, Tuple, Union
 
 import requests
 from pytrie import StringTrie
 
 __all__ = [
     "Converter",
+    "chain",
 ]
 
 
@@ -41,6 +42,8 @@ class Converter:
 
     #: The expansion dictionary with prefixes as keys and priority URI prefixes as values
     data: Mapping[str, str]
+    #: The mapping from URI prefixes to prefixes
+    reverse_data: Mapping[str, str]
     #: A prefix trie for efficient parsing of URIs
     trie: StringTrie
 
@@ -53,29 +56,30 @@ class Converter:
             with the first element of the list being the priority URI prefix for expansions.
         :param delimiter:
             The delimiter used for CURIEs. Defaults to a colon.
-
-        .. warning::
-
-            The ``Converter.__init__`` is subject to change to accommodate more complex
-            prefix map formulations, so it's best to use class methods like :meth:`from_prefix_map`
-            to instantiate Converter objects.
         """
         self.delimiter = delimiter
         self.data = {prefix: uri_prefixes[0] for prefix, uri_prefixes in data.items()}
-        self.trie = StringTrie(
-            {
-                uri_prefix: prefix
-                for prefix, uri_prefixes in data.items()
-                for uri_prefix in uri_prefixes
-            }
-        )
+        self.reverse_data = {
+            uri_prefix: prefix
+            for prefix, uri_prefixes in data.items()
+            for uri_prefix in uri_prefixes
+        }
+        self.trie = StringTrie(self.reverse_data)
 
     @classmethod
     def from_prefix_map(cls, prefix_map: Mapping[str, str]) -> "Converter":
         """Get a converter from a simple prefix map.
 
         :param prefix_map:
-            A mapping whose keys are prefixes and whose values are the corresponding URI prefixes
+            A mapping whose keys are prefixes and whose values are the corresponding *URI prefixes*).
+
+            .. note::
+
+                It's possible that some *URI prefixes* (values in this mapping)
+                partially overlap (e.g.,``http://purl.obolibrary.org/obo/GO_`` for the prefix ``GO`` and
+                ``http://purl.obolibrary.org/obo/`` for the prefix ``OBO``). The longest URI prefix will always
+                be matched. For example, parsing ``http://purl.obolibrary.org/obo/GO_0032571``
+                will return ``GO:0032571`` instead of ``OBO:GO_0032571``.
         :returns:
             A converter
 
@@ -100,6 +104,14 @@ class Converter:
             A mapping whose keys are URI prefixes and whose values are the corresponding prefixes.
             This data structure allow for multiple different URI formats to point to the same
             prefix.
+
+            .. note::
+
+                It's possible that some *URI prefixes* (keys in this mapping)
+                partially overlap (e.g., ``http://purl.obolibrary.org/obo/GO_`` for the prefix ``GO`` and
+                ``http://purl.obolibrary.org/obo/`` for the prefix ``OBO``). The longest URI prefix will always
+                be matched. For example, parsing ``http://purl.obolibrary.org/obo/GO_0032571``
+                will return ``GO:0032571`` instead of ``OBO:GO_0032571``.
         :return:
             A converter
 
@@ -242,6 +254,15 @@ class Converter:
         >>> converter.expand("CHEBI:138488")
         'http://purl.obolibrary.org/obo/CHEBI_138488'
         >>> converter.expand("missing:0000000")
+
+        .. note::
+
+            If there are partially overlapping *URI prefixes* in this converter
+            (e.g., ``http://purl.obolibrary.org/obo/GO_`` for the prefix ``GO`` and
+            ``http://purl.obolibrary.org/obo/`` for the prefix ``OBO``), the longest
+            URI prefix will always be matched. For example, parsing
+            ``http://purl.obolibrary.org/obo/GO_0032571`` will return ``GO:0032571``
+            instead of ``OBO:GO_0032571``.
         """
         prefix, identifier = curie.split(self.delimiter, 1)
         return self.expand_pair(prefix, identifier)
@@ -270,3 +291,19 @@ class Converter:
         if uri_prefix is None:
             return None
         return uri_prefix + identifier
+
+
+def chain(converters: Sequence[Converter]) -> Converter:
+    """Chain several converters.
+
+    :param converters: A list or tuple of converters
+    :returns:
+        A converter that looks up one at a time in the other converters.
+    :raises ValueError:
+        If there are no converters
+    """
+    if not converters:
+        raise ValueError
+    return Converter.from_reverse_prefix_map(
+        ChainMap(*(dict(converter.reverse_data) for converter in converters))
+    )
